==> certbot-dns-selectel-v2-1.2.0.tar.gz: certbot-dns-selectel-v2-1.2.0/certbot_dns_selectel_v2/dns_selectel_test.py <==
#   Copyright 2019 Nikolay Shamanovich shm013@yandex.ru
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.

"""Tests for certbot_dns_selectel_v2.dns_selectel."""

import unittest

import selectel_dns_api
import mock

from certbot import errors
from certbot.compat import os
from certbot.plugins import dns_test_common
from certbot.plugins.dns_test_common import DOMAIN
from certbot.tests import util as test_util

API_KEY = '0000000000000000000000000_000000'

class AuthenticatorTest(test_util.TempDirTestCase, dns_test_common.BaseAuthenticatorTest):

    def setUp(self):
        from certbot_dns_selectel_v2.dns_selectel import Authenticator

        super(AuthenticatorTest, self).setUp()

        path = os.path.join(self.tempdir, 'file.ini')
        dns_test_common.write(
            {"selectel_api_key": API_KEY,},
            path
        )

        self.config = mock.MagicMock(selectel_credentials=path,
                                     selectel_propagation_seconds=0)  # don't wait during tests

        self.auth = Authenticator(self.config, "selectel")

        self.mock_client = mock.MagicMock()
        # _get_selectel_client | pylint: disable=protected-access
        self.auth._get_selectel_client = mock.MagicMock(return_value=self.mock_client)

    def test_perform(self):
        self.auth.perform([self.achall])

        expected = [mock.call.add_txt_record(DOMAIN, '_acme-challenge.'+DOMAIN, mock.ANY, mock.ANY)]
        self.assertEqual(expected, self.mock_client.mock_calls)

    def test_cleanup(self):
        # _attempt_cleanup | pylint: disable=protected-access
        self.auth._attempt_cleanup = True
        self.auth.cleanup([self.achall])

        expected = [mock.call.del_txt_record(DOMAIN, '_acme-challenge.'+DOMAIN, mock.ANY)]
        self.assertEqual(expected, self.mock_client.mock_calls)


class CloudflareClientTest(unittest.TestCase):
    pass

if __name__ == "__main__":
    unittest.main()  # pragma: no cover

==> certbot-dns-selectel-v2-1.4.0.tar.gz: certbot-dns-selectel-v2-1.4.0/certbot_dns_selectel_v2/dns_selectel_test.py <==
#   Copyright 2019 Nikolay Shamanovich shm013@yandex.ru
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.

"""Tests for certbot_dns_selectel_v2.dns_selectel."""

import unittest

import selectel_dns_api
import mock

from certbot import errors
from certbot.compat import os
from certbot.plugins import dns_test_common
from certbot.plugins.dns_test_common import DOMAIN
from certbot.tests import util as test_util

API_KEY = '0000000000000000000000000_000000'

class AuthenticatorTest(test_util.TempDirTestCase, dns_test_common.BaseAuthenticatorTest):

    def setUp(self):
        from certbot_dns_selectel_v2.dns_selectel import Authenticator

        super(AuthenticatorTest, self).setUp()

        path = os.path.join(self.tempdir, 'file.ini')
        dns_test_common.write(
            {"selectel_api_key": API_KEY,},
            path
        )

        self.config = mock.MagicMock(selectel_v2_credentials=path,
                                     selectel_v2_propagation_seconds=0)  # don't wait during tests

        self.auth = Authenticator(self.config, "selectel_v2")

        self.mock_client = mock.MagicMock()
        # _get_selectel_client | pylint: disable=protected-access
        self.auth._get_selectel_client = mock.MagicMock(return_value=self.mock_client)

    def test_perform(self):
        self.auth.perform([self.achall])

        expected = [mock.call.add_txt_record(DOMAIN, '_acme-challenge.'+DOMAIN, mock.ANY, mock.ANY)]
        self.assertEqual(expected, self.mock_client.mock_calls)

    def test_cleanup(self):
        # _attempt_cleanup | pylint: disable=protected-access
        self.auth._attempt_cleanup = True
        self.auth.cleanup([self.achall])

        expected = [mock.call.del_txt_record(DOMAIN, '_acme-challenge.'+DOMAIN, mock.ANY)]
        self.assertEqual(expected, self.mock_client.mock_calls)


class CloudflareClientTest(unittest.TestCase):
    pass

if __name__ == "__main__":
    unittest.main()  # pragma: no cover
